from setuptools import setup, find_packages

setup(
    name='forest305',
    version='0.0.1',
    description='A collection of functions',
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',
    author='Jeff Song',
    author_email='jeff.song0305@gmail.com',
    license='MIT',
    packages=find_packages(),
    install_requires = ['']
)